@@ -8,7 +8,7 @@ package Future::AsyncAwait;
 use strict;
 use warnings;
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 use Carp;
 
@@ -108,10 +108,9 @@ implementation. Some things will randomly break. While it seems stable enough
 for small-scale development and experimental testing, don't expect to be able
 to use this module reliably in production yet.
 
-=head2 Things That Work Already
+=head2 Things That Work
 
-Most simple cases involving awaiting on still-pending futures should be
-working:
+Most cases involving awaiting on still-pending futures should work fine:
 
    async sub foo
    {
@@ -297,10 +296,16 @@ Clean up the implementation; check for and fix memory leaks.
 
 =item *
 
-Support older versions of perl than 5.20.
+Support older versions of perl than 5.18.
 
 L<https://rt.cpan.org/Ticket/Display.html?id=122252>
 
+=item *
+
+Support sub signatures in recent perls.
+
+L<https://rt.cpan.org/Ticket/Display.html?id=124122>
+
 =back
 
 =head1 ACKNOWLEDGEMENTS
